@@ -12,12 +12,10 @@ nb_runs = 0
 
 
 class SideEffectInterface(EngineTestInterface):
-
     def _run_interface(self, runtime):
         global nb_runs
         nb_runs += 1
-        runtime.returncode = 0
-        return runtime
+        return super(SideEffectInterface, self)._run_interface(runtime)
 
 
 def test_caching(tmpdir):
@@ -25,7 +23,7 @@ def test_caching(tmpdir):
     try:
         # Prevent rerun to check that evaluation is computed only once
         config.set('execution', 'stop_on_first_rerun', 'true')
-        mem = Memory(str(tmpdir))
+        mem = Memory(tmpdir.strpath)
         first_nb_run = nb_runs
         results = mem.cache(SideEffectInterface)(input1=2, input2=1)
         assert nb_runs == first_nb_run + 1
@@ -40,4 +38,3 @@ def test_caching(tmpdir):
         assert results.outputs.output1 == [1, 1]
     finally:
         config.set('execution', 'stop_on_first_rerun', old_rerun)
-
