@@ -36,24 +36,18 @@ for each log message.) This can have potentially performance implications. In my
 testing, performance was more than adequate, but if you need a high-volume or
 low-latency solution, I suggest you look elsewhere.
 
-This module currently only support the 'nt' and 'posix' platforms due to the
-usage of the portalocker module.  I do not have access to any other platforms
-for testing, patches are welcome.
-
 See the README file for an example usage of this module.
 
 """
 
 from builtins import range
 
-
 __version__ = "$Id: cloghandler.py 6175 2009-11-02 18:40:35Z lowell $"
 __author__ = "Lowell Alleman"
 __all__ = [
     "ConcurrentRotatingFileHandler",
 ]
 
-
 import os
 import sys
 from random import randint
@@ -65,15 +59,7 @@ try:
 except ImportError:
     codecs = None
 
-
-# Question/TODO: Should we have a fallback mode if we can't load portalocker /
-# we should still be better off than with the standard RotattingFileHandler
-# class, right? We do some rename checking... that should prevent some file
-# clobbering that the builtin class allows.
-
-# sibling  module than handles all the ugly platform-specific details of file locking
-from .portalocker import lock, unlock, LOCK_EX, LOCK_NB, LockException
-
+from filelock import SoftFileLock
 
 # A client can set this to true to automatically convert relative paths to
 # absolute paths (which will also hide the absolute path warnings)
@@ -87,8 +73,15 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
     write to the log file concurrently, but this may mean that the file will
     exceed the given size.
     """
-    def __init__(self, filename, mode='a', maxBytes=0, backupCount=0,
-                 encoding=None, debug=True, supress_abs_warn=False):
+
+    def __init__(self,
+                 filename,
+                 mode='a',
+                 maxBytes=0,
+                 backupCount=0,
+                 encoding=None,
+                 debug=True,
+                 supress_abs_warn=False):
         """
         Open the specified file and use it as the stream for logging.
 
@@ -151,9 +144,10 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
                 filename = os.path.abspath(filename)
             elif not supress_abs_warn:
                 from warnings import warn
-                warn("The given 'filename' should be an absolute path.  If your "
-                     "application calls os.chdir(), your logs may get messed up. "
-                     "Use 'supress_abs_warn=True' to hide this message.")
+                warn(
+                    "The given 'filename' should be an absolute path.  If your "
+                    "application calls os.chdir(), your logs may get messed up. "
+                    "Use 'supress_abs_warn=True' to hide this message.")
         try:
             BaseRotatingHandler.__init__(self, filename, mode, encoding)
         except TypeError:  # Due to a different logging release without encoding support  (Python 2.4.1 and earlier?)
@@ -164,11 +158,8 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
         self.maxBytes = maxBytes
         self.backupCount = backupCount
         # Prevent multiple extensions on the lock file (Only handles the normal "*.log" case.)
-        if filename.endswith(".log"):
-            lock_file = filename[:-4]
-        else:
-            lock_file = filename
-        self.stream_lock = open(lock_file + ".lock", "w")
+        self.lock_file = '%s.lock' % filename
+        self.stream_lock = SoftFileLock(self.lock_file)
 
         # For debug mode, swap out the "_degrade()" method with a more a verbose one.
         if debug:
@@ -185,7 +176,7 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
         in 'degraded' mode. """
         # handle thread lock
         Handler.acquire(self)
-        lock(self.stream_lock, LOCK_EX)
+        self.stream_lock.acquire()
         if self.stream.closed:
             self._openFile(self.mode)
 
@@ -202,7 +193,7 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
                 self.stream.close()
         finally:
             try:
-                unlock(self.stream_lock)
+                self.stream_lock.release()
             finally:
                 # release thread lock
                 Handler.release(self)
@@ -232,7 +223,7 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
     def _degrade(self, degrade, msg, *args):
         """ Set degrade mode or not.  Ignore msg. """
         self._rotateFailed = degrade
-        del msg, args   # avoid pychecker warnings
+        del msg, args  # avoid pychecker warnings
 
     def _degrade_debug(self, degrade, msg, *args):
         """ A more colorful version of _degade(). (This is enabled by passing
@@ -264,7 +255,8 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
             # Attempt to rename logfile to tempname:  There is a slight race-condition here, but it seems unavoidable
             tmpname = None
             while not tmpname or os.path.exists(tmpname):
-                tmpname = "%s.rotate.%08d" % (self.baseFilename, randint(0, 99999999))
+                tmpname = "%s.rotate.%08d" % (self.baseFilename,
+                                              randint(0, 99999999))
             try:
                 # Do a rename test to determine if we can successfully rename the log file
                 os.rename(self.baseFilename, tmpname)
@@ -317,15 +309,17 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
         return False
 
     def _shouldRollover(self):
-        if self.maxBytes > 0:                   # are we rolling over?
+        if self.maxBytes > 0:  # are we rolling over?
             try:
-                self.stream.seek(0, 2)  # due to non-posix-compliant Windows feature
+                self.stream.seek(
+                    0, 2)  # due to non-posix-compliant Windows feature
             except IOError:
                 return True
             if self.stream.tell() >= self.maxBytes:
                 return True
             else:
-                self._degrade(False, "Rotation done or not needed at this time")
+                self._degrade(False,
+                              "Rotation done or not needed at this time")
         return False
 
 
