@@ -2,12 +2,10 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 
-import numpy as np
-import nibabel as nb
-
 from ..utils.filemanip import fname_presuffix
 from .base import (SimpleInterface, TraitedSpec, BaseInterfaceInputSpec,
                    traits, File)
+from .. import LooseVersion
 
 
 class RescaleInputSpec(BaseInterfaceInputSpec):
@@ -45,8 +43,8 @@ class Rescale(SimpleInterface):
     Examples
     --------
 
-    To use a high-resolution T1w image as a registration target for a T2\*
-    image, it may be useful to invert the T1w image and rescale to the T2\*
+    To use a high-resolution T1w image as a registration target for a T2\\*
+    image, it may be useful to invert the T1w image and rescale to the T2\\*
     range.
     Using the 1st and 99th percentiles may reduce the impact of outlier
     voxels.
@@ -63,6 +61,9 @@ class Rescale(SimpleInterface):
     output_spec = RescaleOutputSpec
 
     def _run_interface(self, runtime):
+        import numpy as np
+        import nibabel as nb
+
         img = nb.load(self.inputs.in_file)
         data = img.get_data()
         ref_data = nb.load(self.inputs.ref_file).get_data()
@@ -171,6 +172,8 @@ If an image is not reoriented, the original file is not modified
     output_spec = ReorientOutputSpec
 
     def _run_interface(self, runtime):
+        import numpy as np
+        import nibabel as nb
         from nibabel.orientations import (
             axcodes2ornt, ornt_transform, inv_ornt_aff)
 
@@ -184,8 +187,8 @@ If an image is not reoriented, the original file is not modified
         transform = ornt_transform(orig_ornt, targ_ornt)
         affine_xfm = inv_ornt_aff(transform, orig_img.shape)
 
-        # Check can be eliminated when minimum nibabel version >= 2.2
-        if hasattr(orig_img, 'as_reoriented'):
+        # Check can be eliminated when minimum nibabel version >= 2.4
+        if LooseVersion(nb.__version__) >= LooseVersion('2.4.0'):
             reoriented = orig_img.as_reoriented(transform)
         else:
             reoriented = _as_reoriented_backport(orig_img, transform)
@@ -210,7 +213,9 @@ If an image is not reoriented, the original file is not modified
 
 
 def _as_reoriented_backport(img, ornt):
-    """Backport of img.as_reoriented as of nibabel 2.2.0"""
+    """Backport of img.as_reoriented as of nibabel 2.4.0"""
+    import numpy as np
+    import nibabel as nb
     from nibabel.orientations import inv_ornt_aff
     if np.array_equal(ornt, [[0, 1], [1, 1], [2, 1]]):
         return img
@@ -221,13 +226,8 @@ def _as_reoriented_backport(img, ornt):
 
     if isinstance(reoriented, nb.Nifti1Pair):
         # Also apply the transform to the dim_info fields
-        new_dim = list(reoriented.header.get_dim_info())
-        for idx, value in enumerate(new_dim):
-            # For each value, leave as None if it was that way,
-            # otherwise check where we have mapped it to
-            if value is None:
-                continue
-            new_dim[idx] = np.where(ornt[:, 0] == idx)[0]
+        new_dim = [None if orig_dim is None else int(ornt[orig_dim, 0])
+                   for orig_dim in img.header.get_dim_info()]
 
         reoriented.header.set_dim_info(*new_dim)
 
