@@ -25,7 +25,7 @@ from simplejson import load, dump
 from future import standard_library
 
 from .misc import str2bool
-from ..external import portalocker
+from filelock import SoftFileLock
 
 standard_library.install_aliases()
 
@@ -68,6 +68,7 @@ write_provenance = false
 parameterize_dirs = true
 poll_sleep_duration = 2
 xvfb_max_wait = 10
+check_version = true
 
 [monitoring]
 enabled = false
@@ -103,9 +104,8 @@ class NipypeConfig(object):
         self._display = None
         self._resource_monitor = None
 
-        if os.path.exists(config_dir):
-            self._config.read(
-                [os.path.join(config_dir, 'nipype.cfg'), 'nipype.cfg'])
+        self._config.read(
+            [os.path.join(config_dir, 'nipype.cfg'), 'nipype.cfg'])
 
         for option in CONFIG_DEPRECATIONS:
             for section in ['execution', 'logging', 'monitoring']:
@@ -209,9 +209,9 @@ class NipypeConfig(object):
         """Read options file"""
         if not os.path.exists(self.data_file):
             return None
-        with open(self.data_file, 'rt') as file:
-            portalocker.lock(file, portalocker.LOCK_EX)
-            datadict = load(file)
+        with SoftFileLock('%s.lock' % self.data_file):
+            with open(self.data_file, 'rt') as file:
+                datadict = load(file)
         if key in datadict:
             return datadict[key]
         return None
@@ -220,17 +220,17 @@ class NipypeConfig(object):
         """Store config flie"""
         datadict = {}
         if os.path.exists(self.data_file):
-            with open(self.data_file, 'rt') as file:
-                portalocker.lock(file, portalocker.LOCK_EX)
-                datadict = load(file)
+            with SoftFileLock('%s.lock' % self.data_file):
+                with open(self.data_file, 'rt') as file:
+                    datadict = load(file)
         else:
             dirname = os.path.dirname(self.data_file)
             if not os.path.exists(dirname):
                 mkdir_p(dirname)
-        with open(self.data_file, 'wt') as file:
-            portalocker.lock(file, portalocker.LOCK_EX)
-            datadict[key] = value
-            dump(datadict, file)
+        with SoftFileLock('%s.lock' % self.data_file):
+            with open(self.data_file, 'wt') as file:
+                datadict[key] = value
+                dump(datadict, file)
 
     def update_config(self, config_dict):
         """Extend internal dictionary with config_dict"""
@@ -291,6 +291,10 @@ class NipypeConfig(object):
         """Sets the resource monitor on"""
         self.resource_monitor = True
 
+    def disable_resource_monitor(self):
+        """Sets the resource monitor off"""
+        self.resource_monitor = False
+
     def get_display(self):
         """Returns the first display available"""
 
@@ -353,7 +357,7 @@ class NipypeConfig(object):
         if self._display is not None:
             from .. import logging
             self._display.stop()
-            logging.getLogger('interface').debug(
+            logging.getLogger('nipype.interface').debug(
                 'Closing display (if virtual)')
 
 
